@@ -4,24 +4,24 @@ server <- function(){
 }
 
 tile_server <- function(){
-  "https://thredds.daac.ornl.gov/thredds/fileServer/ornldaac/1328/tiles"
+  "https://thredds.daac.ornl.gov/thredds/fileServer/ornldaac/1840/tiles"
 }
 
 ncss_server <- function(frequency, catalog = FALSE){
-  url <- "https://thredds.daac.ornl.gov/thredds/ncss/ornldaac/"
+  url <- "https://thredds.daac.ornl.gov/thredds/ncss/ornldaac"
   
   if(catalog){
-    return(file.path(url, "/1328/catalog.html"))
+    return(file.path(url, "/1840/catalog.html"))
   }
   
   # set final url path depending on the frequency of the
   # data requested
   if(frequency == "monthly"){
-    url <- sprintf("%s/%s", url, 1345)
+    url <- sprintf("%s/%s", url, 1855)
   } else if (frequency == "annual"){
-    url <- sprintf("%s/%s", url, 1343)
+    url <- sprintf("%s/%s", url, 1852)
   } else {
-    url <- sprintf("%s/%s", url, 1328)
+    url <- sprintf("%s/%s", url, 1840)
   }
 }
 
