@@ -1,8 +1,7 @@
 context("test tile downloads")
-server_check <- daymet_running(tile_server())
 
 test_that("download tile",{
-  skip_if_not(server_check)
+  skip_on_cran()
   expect_message(download_daymet_tiles(
     tiles = 9753,
     start = 1980,
@@ -14,7 +13,7 @@ test_that("download tile",{
 })
 
 test_that("bad start year",{
-  skip_if_not(server_check)
+  skip_on_cran()
   expect_error(download_daymet_tiles(
     tiles = 9753,
     start = 1970,
@@ -25,7 +24,7 @@ test_that("bad start year",{
 })
 
 test_that("bad end year",{
-  skip_if_not(server_check)
+  skip_on_cran()
   expect_error(download_daymet_tiles(
     tiles = 9753,
     start = 1980,
@@ -36,7 +35,7 @@ test_that("bad end year",{
 })
 
 test_that("download tiles by bounding box",{
-  skip_if_not(server_check)
+  skip_on_cran()
   expect_message(download_daymet_tiles(
     location = c(18.9103, -114.6109, 18.6703, -114.2181),
     start = 1980,
@@ -47,7 +46,7 @@ test_that("download tiles by bounding box",{
 })
 
 test_that("missing coordinate value",{
-  skip_if_not(server_check)
+  skip_on_cran()
   expect_error(    download_daymet_tiles(
     location = c(18.9103,
                  -114.6109,
@@ -60,7 +59,7 @@ test_that("missing coordinate value",{
 })
 
 test_that("out of range bbox coordinates",{
-  skip_if_not(server_check)
+  skip_on_cran()
   expect_error(download_daymet_tiles(
     location = c(0,0,0.1,0.1),
     start = 1980,
@@ -71,7 +70,7 @@ test_that("out of range bbox coordinates",{
 })
 
 test_that("out of range coordinate pair",{
-  skip_if_not(server_check)
+  skip_on_cran()
   expect_error(download_daymet_tiles(
     location = c(0, 0),
     start = 1980,
